intake-axds
==============================
[![Build Status](https://img.shields.io/github/workflow/status/axiom-data-science/intake-axds/Tests?logo=github&style=for-the-badge)](https://github.com/axiom-data-science/intake-axds/actions)
[![Code Coverage](https://img.shields.io/codecov/c/github/axiom-data-science/intake-axds.svg?style=for-the-badge)](https://codecov.io/gh/axiom-data-science/intake-axds)
[![License:MIT](https://img.shields.io/badge/License-MIT-green.svg?style=for-the-badge)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://img.shields.io/readthedocs/intake-axds/latest.svg?style=for-the-badge)](https://intake-axds.readthedocs.io/en/latest/?badge=latest)
[![Code Style Status](https://img.shields.io/github/workflow/status/axiom-data-science/intake-axds/linting%20with%20pre-commit?label=Code%20Style&style=for-the-badge)](https://github.com/axiom-data-science/intake-axds/actions)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/intake-axds.svg?style=for-the-badge)](https://anaconda.org/conda-forge/intake-axds)
[![Python Package Index](https://img.shields.io/pypi/v/intake-axds.svg?style=for-the-badge)](https://pypi.org/project/intake-axds)

Intake interface to Axiom assets

--------

<p><small>Project based on the <a target="_blank" href="https://github.com/jbusecke/cookiecutter-science-project">cookiecutter science project template</a>.</small></p>
